@@ -1,6 +1,6 @@
 from django.apps import AppConfig
 
 
-class francedataConfig(AppConfig):
+class FrancedataConfig(AppConfig):
     default_auto_field = "django.db.models.BigAutoField"
     name = "francedata"
